/**
 ******************************************************************************
 * @file    apds9301.h
 * @author  Radek Kysilka
 * @version V1.0.0
 * @date    14-February-2018
 * @brief   LIS2DH12 header driver file
 ******************************************************************************
 * @attention
 *
 *
 ******************************************************************************
 */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __APDS9301__H
#define __APDS9301__H

#ifdef __cplusplus
extern "C" {
#endif
  
/* Includes ------------------------------------------------------------------*/
#include "../Common/lightsense.h"

/** @addtogroup BSP
  * @{
  */

/** @addtogroup Component
  * @{
  */

/** @addtogroup APDS9301
  * @{
  */

/** @defgroup APDS9301_Exported_Constants APDS9301 Exported Constants
  * @{
  */
/************** I2C Address *****************/

#define APDS9301_I2C_ADDRESS_A   0x52  // ADDR = GND
#define APDS9301_I2C_ADDRESS_B   0x72  // ADDR = Float
#define APDS9301_I2C_ADDRESS_C   0x92  // ADDR = VDD

/************** Who am I  *******************/

#define APDS9301_WHO_AM_I     				0x50
#define APDS9301_WHO_AM_I_PARTNUMBER_MASK   0xF0	/* Part Number bits to check */
#define APDS9301_WHO_AM_I_REVISION_MASK   	0x0F	/* Chip Revision bits to check */

/************** Device Register  *******************/

#define APDS9301_REG_COMMAND		  0x80
#define APDS9301_REG_WORD_READ 		0x20

#define APDS9301_REG_CONTROL      0x00
#define APDS9301_BIT_POWERUP		  0x03
#define APDS9301_BIT_POWERDOWN		0x00

#define APDS9301_REG_TIMING       0x01
#define APDS9301_BIT_GAIN_16X     0x10
#define APDS9301_BIT_GAIN_1X		  0x00
#define APDS9301_BIT_INTEG_13MS		0x00
#define APDS9301_BIT_INTEG_402MS	0x02


#define APDS9301_REG_ID		        0x0a

#define APDS9301_REG_DATA0_LOW		0x0c
#define APDS9301_REG_DATA0_HIGH		0x0d
#define APDS9301_REG_DATA1_LOW		0x0e
#define APDS9301_REG_DATA1_HIGH		0x0f


/** @defgroup APDS9301_AccExported_Functions LIGHTSENSOR Exported functions
  * @{
  */ 
void    APDS9301_LightSenseInit(uint8_t i2caddr, uint16_t InitStruct);
void    APDS9301_LightSenseDeInit(uint8_t i2caddr);
uint8_t APDS9301_LightSenseReadID(uint8_t i2caddr);
void    APDS9301_LightSenseLowPower(uint8_t i2caddr, uint16_t status);
void    APDS9301_LightSenseRead(uint8_t i2caddr, uint16_t* pData);

/** @defgroup LSM6DS3_AccImported_Globals  ACCELEROMETER Imported Globals
  * @{
  */
extern LIGHTSENSE_DrvTypeDef Apds9301LightSensorDrv;
/**
  * @}
  */


/** @defgroup APDS9301_Imported_Functions APDS9301 Imported Functions
 * @{
 */
/* IO functions */
extern void     SENSOR_IO_Init(void);
extern void     SENSOR_IO_Write(uint8_t Addr, uint8_t Reg, uint8_t Value);
extern uint8_t  SENSOR_IO_Read(uint8_t Addr, uint8_t Reg);
extern uint16_t SENSOR_IO_ReadMultiple(uint8_t Addr, uint8_t Reg, uint8_t *Buffer, uint16_t Length);
extern void     SENSOR_IO_WriteMultiple(uint8_t Addr, uint8_t Reg, uint8_t *Buffer, uint16_t Length);
/**
  * @}
  */

#ifdef __cplusplus
}
#endif

#endif 
/* __APDS9301__H */
